@@ -1,5 +1,4 @@
-#include "config.h"
-#include <gtkcrystalviewer.h>
+#include <gcu/gtkcrystalviewer.h>
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -23,7 +22,7 @@ int main(int argc, char *argv[])
 		 NULL);
 
 	if (argc >= 2) filename = argv[1];
-		else filename = SRCDIR"/tests/nickel.gcrystal";
+		else filename = "nickel.gcrystal";
 	xml = xmlParseFile(filename);
 	
 	viewer = gtk_crystal_viewer_new(xml->children);
